import enum
import requests
from typing import NamedTuple
from bs4 import BeautifulSoup as bs


class Rashi(NamedTuple):
    rashi: str
    date: str


class Zodiacs(enum.Enum):
    Mesh = 'Mesh'
    Mithun = 'Mithun'
    Singha = 'Singha'
    Tula = 'Tula'
    Dhanu = 'Dhanu'
    Kumbha = 'Kumbha'
    Brish = 'Brish'
    Karkat = 'Karkat'
    Kanya = 'Kanya'
    Brischik = 'Brischik'
    Makar = 'Makar'
    Meen = 'Meen'


class Length(enum.Enum):
    Daily = 'daily'
    Weekly = 'weekly'
    Monthly = 'monthly'
    Yearly = 'yearly'


def getRashiFal(zodiac: Zodiacs, length: Length) -> Rashi:
    baseURL = f"https://www.hamropatro.com/rashifal/{length.value}/{zodiac.value}"
    print(baseURL)
    response = requests.get(baseURL).content
    soup = bs(response, "html.parser")
    rashi: str = soup.find_all("p")[0].text.split("- ज्य")[0]
    rashiDate: str = soup.select(
        "#content > div > div:nth-child(1) > div.container12 > div.column7 > h2 > span > a")[0].text
    return Rashi(rashi, rashiDate)


if __name__ == "__main__":
    rashi = getRashiFal(Zodiacs.Meen, Length.Weekly)
    print(rashi.rashi)
    print(rashi.date)



from setuptools import setup, find_packages

with open('README.md') as f:
    long_description = f.read()

VERSION = '0.1.1'
DESCRIPTION = 'Get Rashi'
LONG_DESCRIPTION = 'A simple package that scrapes out `rashi fals` from https: // www.hamropatro.com/rashifal'

# Setting up
setup(
    name="rashi",
    version=VERSION,
    author="Crain69 (Chirayu Prasai)",
    description=DESCRIPTION,
    author_email="<chirayuprasai11@gmail.com>",
    url="https://github.com/Crian69/rashi",
    long_description_content_type="text/markdown",
    long_description=long_description,
    packages=find_packages(),
    install_requires=["beautifulsoup4", "requests"],
    keywords=['python', 'nepali', 'rashi','hamro', 'patro', 'horoscope'],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: Microsoft :: Windows",
    ])
